/////////////////////////////////////////////
//
// Oct/2013  E. Nacher --> PhysicsList.cc
//
/////////////////////////////////////////////

#include "globals.hh"
#include "PhysicsList.hh"

//#include "G4EmStandardPhysics.hh"
#include "G4EmStandardPhysics_option3.hh"

//#include "G4NeutronHPorLEModel.hh"
#include "G4HadronElasticPhysics.hh"
#include "G4HadronElasticProcess.hh"
//#include "G4HadronPhysicsLHEP.hh"
//#include "G4HadronPhysicsQGSP_BIC_AllHP.hh"
//#include "G4HadronInelasticQBBC.hh"
#include "G4HadronPhysicsQGSP_BERT.hh"
#include "G4Neutron.hh"

#include "G4RadioactiveDecayPhysics.hh"
#include "G4DecayPhysics.hh"

#include "G4LossTableManager.hh"

#include "G4ProcessManager.hh"
#include "G4ParticleTypes.hh"

#include "G4BosonConstructor.hh"


using namespace CLHEP;

PhysicsList::PhysicsList():  G4VUserPhysicsList()
{
	defaultCutValue = 0.05*mm;
	SetVerboseLevel(2);
	
	//electromagnetic physics
//	emPhysicsList = new G4EmStandardPhysics();
	emPhysicsList = new G4EmStandardPhysics_option3();
	
	//decay physics
	decayParticleList = new G4DecayPhysics();
	decayPhysicsList =  new G4RadioactiveDecayPhysics();

	//hadron physics
	//hadronElasticPhysicsList = new G4HadronElasticPhysics();
	hadronPhysicsList = new G4HadronPhysicsQGSP_BERT(); // G4HadronInelasticQBBC(); //  G4HadronPhysicsQGSP_BIC_AllHP(); //HadronPhysicsLHEP();
}

PhysicsList::~PhysicsList()
{}

void PhysicsList::ConstructParticle()
{	
	// gamma, e+, e- and some charged Hadrons
	emPhysicsList    ->ConstructParticle();
	decayParticleList ->ConstructParticle();

	// neutrons
	G4BosonConstructor  pBosonConstructor;
	pBosonConstructor.ConstructParticle();
	G4Neutron::NeutronDefinition();
}



void PhysicsList::ConstructProcess()
{
	AddTransportation();
	
	emPhysicsList->ConstructProcess();
	decayParticleList->ConstructProcess();
	decayPhysicsList->ConstructProcess();

	//hadronElasticPhysicsList->ConstructProcess();
	hadronPhysicsList->ConstructProcess();


}

void PhysicsList::SetCuts()
{
	// default cut value for all particle types 
	SetCutsWithDefault();
	
	if (verboseLevel>0) DumpCutValuesTable();
}
