//////////////////////////////////////////////
//
// Apr/2018  M. Labiche --> RunAction.cc
//
//////////////////////////////////////////////

#include "G4Run.hh"
#include "RunAction.hh"
#include "G4RunManager.hh"
#include "G4UnitsTable.hh"
#include "G4SystemOfUnits.hh"

#include "Analysis.hh"

#include "G4ios.hh"
#include "fstream"
#include "iomanip"

using namespace std;

RunAction::RunAction()
{
	  // Create analysis manager
  // The choice of analysis technology is done via selectin of a namespace
  // in B4Analysis.hh
  G4AnalysisManager* analysisManager = G4AnalysisManager::Instance();
  G4cout << "Using " << analysisManager->GetType() << G4endl;

  // Create directories 
  //analysisManager->SetHistoDirectoryName("histograms");
  //analysisManager->SetNtupleDirectoryName("ntuple");
  analysisManager->SetVerboseLevel(1);
  analysisManager->SetFirstHistoId(1);

  // Book histograms, ntuple
  //
  
  // Creating histograms
//  analysisManager->CreateH1("Cell_13_Energy_proton","Energy spectrum measured in the Cell 13", 5500, 0, 100*MeV); // 0
//  analysisManager->CreateH1("Cell_13_Energy_Xray","Energy spectrum measured in the Cell 13", 5500, 0, 1*MeV); // 0

for(G4int i=0;i<27;i++){
 G4String histoName1="Cell_";
 G4String histoName2="_Energy";
 //G4String histoName2="_Energy_Xray";
 //G4String histoName3="_Energy_Proton";

 G4String histoNameA= histoName1+to_string(i)+histoName2;
 //G4String histoNameB= histoName1+to_string(i)+histoName3;
 G4String histotitle ="Energy in Cell"+to_string(i);
 analysisManager->CreateH1(histoNameA, histotitle, 100000, 0, 100*MeV);     // any
  //analysisManager->CreateH1(histoNameA, histotitle, 5500, 0, 1*MeV);     // Xray
  //analysisManager->CreateH1(histoNameB, histotitle, 5500, 0, 100*MeV);   // Proton


}

/*  analysisManager->CreateH1("Cell_0_Energy","Energy spectrum measured in the Cell 0", 5500, 0, 1*MeV);     // 0
  analysisManager->CreateH1("Cell_1_Energy","Energy spectrum measured in the Cell 12", 5500, 0, 1*MeV);     // 1
  analysisManager->CreateH1("Cell_2_Energy","Energy spectrum measured in the Cell 13", 5500, 0, 1*MeV);     // 2
  analysisManager->CreateH1("Cell_3_Energy","Energy spectrum measured in the Cell 14", 5500, 0, 1*MeV);     // 3
*/
//  analysisManager->CreateH1("NaI_Energy","Energy spectrum measured in NaI detecor", 5500, 0, 5500*keV);

	 }

RunAction::~RunAction()
{ 
	 delete G4AnalysisManager::Instance();  
	}

void RunAction::BeginOfRunAction(const G4Run*)
{
    
   // Get analysis manager
  G4AnalysisManager* analysisManager = G4AnalysisManager::Instance();

  // Open an output file
  //
  G4String fileName = "EnergySpectrum";
  analysisManager->OpenFile(fileName);   
    
    
    
 //   
 // Also, for ASCII file:  
 //
    // histogram length and range
    NumberChannel = 4000;  // number of channels
    EnergyRange = 100.0;   // range in MeV
    EnergyRange2 = 0.1;   // range in MeV
    
    // reset histograms
    for(G4int ind=0; ind < NumberChannel; ind++)
    {
        Histogram[ind] = 0.;
        Histogram2[ind] = 0.;
    }
    
    
}

void RunAction::EndOfRunAction(const G4Run*)
{

  // save ROOT histograms & ntuple
  // 
  G4AnalysisManager* analysisManager = G4AnalysisManager::Instance();
  	

  analysisManager->Write();
  analysisManager->CloseFile();
	
  // Also for ASCII file:
  //write histograms
    
    ofstream histogramOutputFile("../data/pulseHeightSpectrum.dat");
    
    if(NumberChannel > 0)
    {
        for(G4int ind=0; ind < NumberChannel; ind++){
            histogramOutputFile << setw(6) << ind <<
            setw(10) << Histogram[ind] << G4endl;
            
        }
    }
}

void RunAction::fillHistogram(G4double Energy)
{
	// Only for ASCII file:
    
    G4double bin;
    G4int ibin;
    
    if(NumberChannel > 0)
    {
        bin = Energy/EnergyRange*NumberChannel;
        ibin = bin + 1 ;
        if(ibin > NumberChannel-1) ibin = NumberChannel-1;
        Histogram[ibin] += 1.;
        
    }
}

